@@ -49,7 +49,7 @@ def _read_trace_states(path_or_bytes):
         delimiter="\t",
         usecols=[1, 2, 3, 4, 5, 6, 7, 8, 10],
         skipinitialspace=True,
-        dtype={"SAT": _gn_const.PRN_CATEGORY, "TYPE": _gn_const.STATE_TYPES_CATEGORY},
+        dtype={"SAT": _gn_const.PRN_CATEGORY, "TYPE": object},
         keep_default_na=False,
         comment="#",
         header=None,
@@ -63,7 +63,7 @@ def _read_trace_states(path_or_bytes):
 
     df.TIME = _gn_datetime.datetime2j2000(df.TIME.values)
 
-    empty_mask = df.TYPE.values.notna()  # dropping ONE type
+    empty_mask = df.TYPE.notna()  # dropping ONE type
     if (~empty_mask).sum() > 0:
         df = df[empty_mask]
 
