@@ -15,9 +15,6 @@ def diffutil_verify_input(input):
             _click.echo(f"Error: Missing argument {i} of '-i' / '--input'.")
             _sys.exit(-1)
         _click.Path(exists=True)(input[i])
-
-    _logging.getLogger().setLevel(_logging.INFO)
-    _logging.info(f":diffutil ========== STARTING DIFFUTIL ==========")
     _logging.info(f":diffutil input1: {_os.path.abspath(input[0])}")
     _logging.info(f":diffutil input2: {_os.path.abspath(input[1])}")
 
@@ -42,7 +39,7 @@ def get_filetype(path):
     """
     basename = _os.path.basename(path)
     suffix = basename.split(".")[1].lower().partition("_")[0]
-    filetype_dict = {"snx": "sinex", "sum": "trace", "eph": "sp3"}
+    filetype_dict = {"snx": "sinex", "sum": "trace", "eph": "sp3", "inx": "ionex"}
     if suffix in filetype_dict.keys():
         return filetype_dict[suffix]
     elif suffix == "out":
@@ -83,6 +80,13 @@ def get_filetype(path):
 )
 @_click.pass_context
 def diffutil(ctx, input, passthrough, atol, coef, log_lvl, plot):
+    _logging.getLogger().setLevel(_logging.INFO)
+    _logging.info(f":diffutil ========== STARTING DIFFUTIL ==========")
+    if not _os.path.exists(input[0]):
+        _logging.error(
+            f":diffutil '{input[0]}' input not found on disk. Please check inputs or diffex expression"
+        )
+        ctx.exit(-1)
     if ctx.invoked_subcommand is None:
         if input is None:
             ctx.fail(ctx.get_help())
